AdsterInterstitialAdsCallback class

Constructors

AdsterInterstitialAdsCallback({required VoidCallback onAdClicked, required VoidCallback onAdImpression, required VoidCallback onAdOpened, required VoidCallback onAdClosed, required dynamic onAdRevenuePaid(double? revenue, String? adUnitId, String? network), void onAdFailToPresentFullScreenContentWithError(AdsterAdsException error)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
onAdClicked VoidCallback
final
onAdClosed VoidCallback
final
onAdFailToPresentFullScreenContentWithError → void Function(AdsterAdsException error)?
final
onAdImpression VoidCallback
final
onAdOpened VoidCallback
final
onAdRevenuePaid → dynamic Function(double? revenue, String? adUnitId, String? network)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited