AdsterNativeCustomAdData class
Constructors
-
AdsterNativeCustomAdData({required String widgetId, String? customFormatId, List<
String> availableAssetNames = const []}) -
const
-
AdsterNativeCustomAdData.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
availableAssetNames
→ List<
String> -
final
- customFormatId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widgetId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited